===================================
Powerline PulseAudio Volume Segment
===================================


Powerline PulseAudio Volume Segment...


* Free software: MIT license
* Documentation: https://powerline-pulseaudio-volume-segment.readthedocs.io.

